@@ -1,4 +1,4 @@
 __author__ = 'Svyatoslav Gagarin <nayls@bk.ru>'
 
-from .pretty import pretty_json
+from .pretty import pretty_json, pretty_json_decode
 from .authentitication import basic_auth
